from setuptools import setup, find_packages

VERSION = '0.0.2'
DESCRIPTION = ''
LONG_DESCRIPTION = ''

# Setting up
setup(
    name="pondos",
    version=VERSION,
    author="dscestudent",
    author_email="<smf9092@newsote.com>",
    description=DESCRIPTION,
    keywords=[],
    include_package_data=True,
    packages=['pondos'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)

